clear; close all

%% Parameters

p = 19; % number of terms in the power series expansion

A = ...
    [ ...
        -2      0   ;...
        1       -1  ...
    ];

x0 = [  1;  .5   ];

tVec = 0:0.1:4;


n = length(x0);
T = length(tVec);

%% Matrix exponential / state transition matrix

Phi = ME370_2015S_eAt( tVec, A, p ); % define state transition matrix

xh = ones(n,1,T)*NaN; % preallocate homogeneous solution
for i = 1:T % for each time, compute the solution
   xh(:,:,i) = Phi(:,:,i) * x0; 
end

%% Analytic solution

x1 = @( tVec ) x0(1) .* exp( -2 * tVec );
x2 = @( tVec ) x0(1) .* ( exp( -tVec ) - exp( -2 * tVec ) ) + x0(2) * exp( -tVec );

%% Plot

figure;
plot( ...
    tVec, ...
    squeeze( xh( 1, 1, : ) ), ...
    '-b', ...
    'LineWidth', 2 ...
); 
hold on
plot( ...
    tVec, ...
    squeeze( xh( 2, 1, : ) ), ...
    '-g', ...
    'LineWidth', 2 ...
);
plot( ...
    tVec, ...
    x1( tVec ), ...
    '--r', ...
    'LineWidth', 2 ...
);
plot( ...
    tVec, ...
    x2( tVec ), ...
    '--m', ...
    'LineWidth', 2 ...
);
grid on
xlabel('time (s)')
ylabel('response')
title('homogeneous response')

%% Export plot

plot_save(gcf,1,0,6,1,1,'matrix_exp_example',0,1,0,0,0)
export_fig